@@ -17,11 +17,6 @@ ggvis = (function(_) {
     return this.plots[plotId];
   };
 
-  // Are we in a panel - an iframe or RStudio viewer pane?
-  ggvis.inPanel = function() {
-    return (queryVar("viewer_pane") === "1" || queryVar("__subapp__") === "1");
-  };
-
   // Internal functions --------------------------------------------------
 
   // Returns the value of a GET variable
@@ -41,6 +36,16 @@ ggvis = (function(_) {
     }
   }
 
+  // Are we in a panel - an iframe or RStudio viewer pane?
+  function inPanel() {
+    return (queryVar("viewer_pane") === "1" || queryVar("__subapp__") === "1");
+  }
+
+  // Are we in a window for exporting the image?
+  function inExportPanel() {
+    return queryVar("viewer_export") === "1";
+  }
+
   // ggvis.CallbackRegistry class ----------------------------------------------
   ggvis.CallbackRegistry = (function() {
     // obj is an object to use as the context for the callbacks
@@ -197,7 +202,11 @@ ggvis = (function(_) {
 
         self.brush.enable();
 
-        if (ggvis.inPanel()) {
+        if (inExportPanel()) {
+          $('.plot-gear-icon').hide();
+        }
+
+        if (inPanel()) {
           self.enableAutoResizeToWindow();
         } else if (opts.resizable) {
           self.enableResizable();
@@ -354,7 +363,7 @@ ggvis = (function(_) {
       this.initialized = true;
 
       // Resizing to fit has to happen after the initial update
-      if (ggvis.inPanel()) {
+      if (inPanel()) {
         this.resizeToWindow(0);
       } else {
         this.resizeWrapperToPlot();
@@ -389,7 +398,7 @@ ggvis = (function(_) {
 
     // This is called when control outputs for a plot are updated
     prototype.onControlOutput = function() {
-      if (ggvis.inPanel()) {
+      if (inPanel()) {
         this.resizeToWindow(0);
       }
     };
@@ -799,10 +808,21 @@ ggvis = (function(_) {
 
       // Internal functions --------------------------------------------
       function mouseOffset(e) {
-        return {
-          x: e.offsetX,
-          y: e.offsetY
-        };
+        // A workaround for Firefox, which doesn't provide offsetX/Y
+        // for mouse event.
+        if (typeof(e.offsetX) === "undefined") {
+          var offset = $(e.currentTarget).offset();
+          return {
+            x: e.pageX - offset.left,
+            y: e.pageY - offset.top
+          };
+        }
+        else {
+          return {
+            x: e.offsetX,
+            y: e.offsetY
+          };
+        }
       }
 
       return brush;
@@ -838,7 +858,7 @@ vg.data.treefacet = function() {
         obj, klist, kstr, len, i, k, kv;
 
     if (keys.length === 0) {
-      throw "Need at least one key"
+      throw "Need at least one key";
     }
 
     for (i=0, len=data.length; i<len; ++i) {
